@@ -27,13 +27,21 @@ class Tree:
     def add_branch(self, branch):
         return self._branches.append(branch)
 
+    def fresh(self):
+        '''find any fresh new branches'''
+        for dir in walkdir.filtered_walk(
+                self._root,
+                excluded_dirs=[settings.BUILD_DIR]):
+            # new:  if the branch in not in branches - add it
+            print self._branches
+            #print dir
+            
+
     def _grow(self):
         '''finds all available branches for tree'''
-
         for dir in walkdir.filtered_walk(
                 self._root,
                 excluded_dirs=[settings.BUILD_DIR]):
-            from omdox import feedback
             # add the branch
             branch = Branch(dir[0], self.root)
             # add the nodes
